@@ -1,6 +1,6 @@
-import objc
-import Cocoa
 import AppDrawing
+import Cocoa
+import objc
 
 
 def getURLToExport(suffix):
@@ -28,7 +28,9 @@ class MyAppController(Cocoa.NSObject):
     def exportAsPNG_(self, sender):
         url = getURLToExport("png")
         if url:
-            AppDrawing.myExportCGDrawingAsPNG(url, self.theView.currentPrintableCommand())
+            AppDrawing.myExportCGDrawingAsPNG(
+                url, self.theView.currentPrintableCommand()
+            )
 
     @objc.IBAction
     def exportAsPDF_(self, sender):
